@@ -15,10 +15,9 @@
  */
 
 import { createSelector } from 'reselect';
-import { List, Map, Set } from 'immutable';
+import { List, Map } from 'immutable';
 
 import { getFilterByName } from './filters';
-import { getRoles } from './roles';
 import { IntrospectionStatus } from '../immutableRecords/nodes';
 import { parseNodeCapabilities } from '../utils/nodes';
 
@@ -32,6 +31,8 @@ export const getNodesByIds = (state, nodeIds) =>
 export const getPorts = state => state.nodes.get('ports');
 export const getIntrospectionData = state =>
   state.nodes.get('introspectionData');
+export const getNodeIntrospectionData = (state, nodeId) =>
+  state.nodes.introspectionData.get(nodeId, Map());
 export const getIntrospectionStatuses = state =>
   state.nodes.get('introspectionStatuses');
 export const nodesInProgress = state => state.nodes.get('nodesInProgress');
@@ -102,11 +103,11 @@ export const getFilteredNodes = createSelector(
       .update(nodes =>
         nodesToolbarFilter.get('activeFilters').reduce(
           (filteredNodes, filter) =>
-            filteredNodes.filter(node => {
-              return getNodePropertyString(node, filter.filterBy)
+            filteredNodes.filter(node =>
+              getNodePropertyString(node, filter.filterBy)
                 .toLowerCase()
-                .includes(filter.filterString.toLowerCase());
-            }),
+                .includes(filter.filterString.toLowerCase())
+            ),
           nodes
         )
       )
@@ -117,26 +118,6 @@ export const getFilteredNodes = createSelector(
       )
 );
 
-/**
- *  Return a list of profiles collected across all nodes
- */
-export const getProfilesList = createSelector(getNodes, nodes =>
-  nodes
-    .reduce((profiles, v, k) => {
-      const profile = getNodeCapabilities(v).profile;
-      return profile ? profiles.push(profile) : profiles;
-    }, List())
-    .sort()
-);
-
-/**
- *  Return a list of profiles merged with role identifiers
- */
-export const getAvailableNodeProfiles = createSelector(
-  [getProfilesList, getRoles],
-  (profiles, roles) => Set.fromKeys(roles).union(profiles).toList().sort()
-);
-
 /*
  * booleam, returns true if there are any nodes with operation in progress
  */
@@ -145,6 +126,20 @@ export const getNodesOperationInProgress = createSelector(
   nodesInProgress => !nodesInProgress.isEmpty()
 );
 
+export const getNodeDrives = createSelector(
+  getNodeIntrospectionData,
+  nodeIntrospectionData =>
+    nodeIntrospectionData
+      .getIn(['inventory', 'disks'], List())
+      .map(disk =>
+        disk.set(
+          'rootDisk',
+          nodeIntrospectionData.getIn(['root_disk', 'name']) ===
+            disk.get('name')
+        )
+      )
+);
+
 /**
  * Helper function to get node capabilities object
  * @param node
